@@ -11,9 +11,9 @@
 clean_data_path <- function(root, file, normalize = TRUE) {
   assert_that(is.flag(normalize), noNA(normalize))
   dir_name <- dirname(file)
-  if (length(grep("\\.\\.", dir_name))) {
-    stop("file should not contain '..'")
-  }
+  assert_that(
+    length(grep("\\.\\.", dir_name)) == 0, msg = "file should not contain '..'"
+  )
 
   file <- gsub("\\..*$", "", basename(file))
   if (dir_name == ".") {
