@@ -25,9 +25,6 @@
 #' upgrade_data(file = "iris", root = root)
 #' # use path = "." to upgrade all git2rdata objects under root
 #' upgrade_data(path = ".", root = root)
-#'
-#' # clean up
-#' junk <- file.remove(list.files(root, full.names = TRUE), root)
 upgrade_data <- function(file, root = ".", verbose, ..., path) {
   UseMethod("upgrade_data", root)
 }
@@ -37,17 +34,15 @@ upgrade_data.default <- function(file, root, verbose, path, ...) {
   stop("a 'root' of class ", class(root), " is not supported", call. = FALSE)
 }
 
-#' @importFrom assertthat assert_that is.string is.flag noNA
+#' @importFrom assertthat assert_that is.string
 #' @importFrom yaml read_yaml write_yaml
 #' @importFrom utils packageVersion
 #' @export
 upgrade_data.character <- function(
   file, root = ".", verbose = TRUE, ..., path) {
-  assert_that(is.string(root), is.flag(verbose), noNA(verbose))
+  assert_that(is.string(root))
   root <- normalizePath(root, winslash = "/", mustWork = TRUE)
   if (missing(file)) {
-    assert_that(missing(file),
-                msg = "specify either 'file' or 'path'")
     assert_that(is.string(path))
     full_path <- normalizePath(file.path(root, path), winslash = "/",
                                mustWork = TRUE)
@@ -64,7 +59,7 @@ upgrade_data.character <- function(
   target <- remove_root(file = file["meta_file"], root = root)
   target <- gsub(".yml", "", target)
   if (!has_name(meta_data, "..generic")) {
-    message(target, "is not a git2rdata object")
+    message(target, " is not a git2rdata object")
     return(target)
   }
   assert_that(
@@ -72,14 +67,56 @@ upgrade_data.character <- function(
     msg = paste(target, "has corrupt metadata, no hash found.")
   )
   if (has_name(meta_data[["..generic"]], "git2rdata")) {
-    if (package_version(meta_data[["..generic"]][["git2rdata"]]) >=
-        package_version("0.1.0.9001")
-        ) {
-      if (verbose) {
-        message(target, " already up to date")
-      }
+    current <- package_version(meta_data[["..generic"]][["git2rdata"]])
+    if (current >= package_version("0.4.0")) {
+      display(verbose, c(target, " already up to date"))
       return(target)
     }
+    assert_that(
+      has_name(meta_data[["..generic"]], "optimize"),
+      msg = paste(target, "has corrupt metadata, optimize flag not found.")
+    )
+    assert_that(
+      current >= package_version("0.2.0"),
+      msg = "Data stored with ancient version of git2rdata.
+Please install version 0.3.1 and upgrade to that version first.
+Then reinstall the current version and upgrade to this version.
+Install version 0.3.1 with remotes::install_github('ropensci/git2rdata@v0.3.1')"
+    )
+    if (meta_data[["..generic"]][["optimize"]]) {
+      display(verbose, c(target, " already up to date"))
+      return(target)
+    }
+    na_string <- meta_data[["..generic"]][["NA string"]]
+    details <- meta_data[names(meta_data) != "..generic"]
+    col_names <- names(details)
+    col_classes <- vapply(details, "[[", character(1), "class")
+    col_type <- c(
+      character = "character", factor = "character", integer = "integer",
+      numeric = "numeric", logical = "logical", Date = "Date",
+      POSIXct = "character", complex = "complex"
+    )
+    old <- read.table(
+      file = file["raw_file"], header = TRUE, sep = "\t", quote = "\"",
+      dec = ".", numerals = "warn.loss", na.strings = na_string,
+      colClasses = setNames(col_type[col_classes], col_names),
+      comment.char = "",
+      stringsAsFactors = FALSE, fileEncoding = "UTF-8"
+    )
+    file.remove(file["raw_file"])
+    file["raw_file"] <- gsub("\\.tsv$", ".csv", file["raw_file"])
+    for (i in which(col_type[col_classes] == "character")) {
+      x <- gsub("\\\"", "\\\"\\\"", old[[i]])
+      to_escape <- grepl("(\"|,|\n)", x)
+      x[to_escape] <- paste0("\"", x[to_escape], "\"")
+      x[is.na(x)] <- na_string
+      old[[i]] <- x
+    }
+    write.table(
+      x = old, file = file["raw_file"],
+      append = FALSE, quote = FALSE, sep = ",", eol = "\n", na = na_string,
+      dec = ".", row.names = FALSE, col.names = TRUE, fileEncoding = "UTF-8"
+    )
     meta_data[["..generic"]][["git2rdata"]] <- NULL
     meta_data[["..generic"]][["data_hash"]] <- NULL
   }
@@ -92,9 +129,7 @@ upgrade_data.character <- function(
     meta_data[["..generic"]][["data_hash"]] <- datahash(file["raw_file"])
   }
   write_yaml(meta_data, file["meta_file"], fileEncoding = "UTF-8")
-  if (verbose) {
-    message(file["meta_file"], " updated")
-  }
+  display(verbose, c(file["meta_file"], " updated"))
   return(target)
 }
 
@@ -114,6 +149,10 @@ upgrade_data.git_repository <- function(
   if (!stage) {
     return(file)
   }
-  add(root, path = paste0(file, ".yml"), force = force)
+
+  file <- gsub("^\\./", "", file)
+  add(root, path = sprintf("%s.csv", file), force = force)
+  add(root, path = sprintf("%s.tsv", file), force = force)
+  add(root, path = sprintf("%s.yml", file), force = force)
   return(file)
 }
